@@ -23,9 +23,7 @@
 #ifndef CONFFILE_H
 #define CONFFILE_H 1
 
-int get_value (char *, char *);
 void init_conf (void);
-void check_return (int, char *, int);
 
 #define isyes(x)	(x[0] == 'y' || x[0] == 'Y' || x[0] == '1')
 
