@@ -20,15 +20,17 @@
  * 02111-1307  USA
  */
 
-#ifndef STRUCTS_H
-#define STRUCTS_H 1
+#ifndef _STRUCTS_H
+#define _STRUCTS_H 1
 
 #include <strings.h>
 #include <pwd.h>
 #include <grp.h>
 #include <sys/types.h>
 
-#define MAXBUF 1024
+#ifndef MAXBUF
+#define MAXBUF 2048
+#endif
 
 /* Configuration info */
 struct config_opt {
@@ -75,4 +77,4 @@ struct file_entry {
 #define FE_CHGRP        0x0100	/* Group id changed */
 #define FE_CHANGEDATTR  0x0174	/* Mask for anything changed */
 
-#endif /* STRUCTS_H */
+#endif /* _STRUCTS_H */
