@@ -41,8 +41,9 @@ FILE *mail_file;
 void init_file_entries (void)
 {
     FILE *log;
-    char buf[1024], *s, *tok;
+    char buf[MAXBUF], *s, *tok, search_tok[2];
 
+    search_tok[1] = '\0';
     global_log = NULL;
     log = fopen (config_options.log_file, "r");
     if (log == NULL)
@@ -53,7 +54,15 @@ void init_file_entries (void)
 
 	buf[strlen (buf) - 1] = '\0';
 	s = buf;
-	tok = strtok (s, " ");
+
+	/* Test if we have an old format log which
+	 * is space delimited */
+	if (strchr(s, 0x1e) == NULL)
+	    search_tok[0] = ' ';
+	else
+	    search_tok[0] = 0x1e;
+
+	tok = strtok (s, search_tok);
 
 	if((config_options.flags & FLAG_SPOT) && 
 		strncasecmp(config_options.search_paths,
@@ -71,15 +80,15 @@ void init_file_entries (void)
 
 	p->path = strdup (tok);
 
-	p->uid = (uid_t) atoi (strtok (NULL, " "));
-	p->gid = (gid_t) atoi (strtok (NULL, " "));
-	p->mode = (mode_t) atoi (strtok (NULL, " "));
-	p->inode = (ino_t) atoi (strtok (NULL, " "));
+	p->uid = (uid_t) atoi (strtok (NULL, search_tok));
+	p->gid = (gid_t) atoi (strtok (NULL, search_tok));
+	p->mode = (mode_t) atoi (strtok (NULL, search_tok));
+	p->inode = (ino_t) atoi (strtok (NULL, search_tok));
 	p->old_uid = -1;
 	p->old_gid = -1;
 	p->old_mode = -1;
 
-	tok = strtok (NULL, " ");
+	tok = strtok (NULL, search_tok);
 	if (tok != NULL)
 	    p->md5 = strdup (tok);
 	else
@@ -212,9 +221,9 @@ void save_and_rotate (void)
     }
     while (p != NULL) {
 	if (!(p->flags & FE_OLD))
-	    fprintf (new_log, "%s %d %d %d %d %s\n", p->path, (int) p->uid,
-		(int) p->gid, (int) p->mode, (int) p->inode,
-		p->md5 != NULL ? p->md5 : "");
+	    fprintf (new_log, "%s%c%d%c%d%c%d%c%d%c%s\n", p->path, 0x1e,
+		(int) p->uid, 0x1e, (int) p->gid, 0x1e, (int) p->mode,
+		0x1e, (int) p->inode, 0x1e, p->md5 != NULL ? p->md5 : "");
 	p = p->next;
     }
 
