@@ -43,11 +43,11 @@ void mail_header (FILE * output)
     fprintf (output, "This host  : %s\n", gethostname (hostname_val,
 	    sizeof (hostname_val)) ? "localhost" : hostname_val);
     if (config_options.flags & FLAG_SPOT)
-	fprintf (output, "Spotcheck : %s\n", config_options.search_paths);
+	fprintf (output, "Spotcheck  : %s\n", config_options.search_paths);
     else
 	fprintf (output, "Searching  : %s\n", config_options.search_paths);
     fprintf (output, "Excluding  : %s\n", config_options.exclude_paths);
-    fprintf (output, "Ingore Dirs: %s\n", config_options.ignore_dirs);
+    fprintf (output, "Ignore Dirs: %s\n", config_options.ignore_dirs);
     fprintf (output, "Forbidden  : %s\n", config_options.forbidden_paths);
     if (config_options.flags & FLAG_EFOR)
 	fprintf (output, "  (enforcing removal of s[ug]id bits in forbidden paths)\n");
